@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
 
 	// badwords
-	if (!function_exists("badwords"))
+	if(!function_exists("badwords"))
 		{
 		function badwords($text)
 			{
@@ -51,11 +51,11 @@
 
 
 	// checks if email is valid
-	if (!function_exists("check_mail"))
+	if(!function_exists("check_mail"))
 		{
 		function check_mail($email)
 			{
-			if (preg_match("/^[a-zA-Z0-9]+([-_\.]?[a-zA-Z0-9])+@[a-zA-Z0-9]+([-_\.]?[a-zA-Z0-9])+\.[a-zA-Z]{2,4}/", $email))
+			if(preg_match("/^[a-zA-Z0-9]+([-_\.]?[a-zA-Z0-9])+@[a-zA-Z0-9]+([-_\.]?[a-zA-Z0-9])+\.[a-zA-Z]{2,4}/", $email))
 				{
 				return TRUE;
 				}
@@ -68,11 +68,11 @@
 
 
 	// checks if icq number is valid
-	if (!function_exists("check_number"))
+	if(!function_exists("check_number"))
 		{
 		function check_number($number)
 			{
-			if (preg_match("=^[0-9]+$=i", $number))
+			if(preg_match("=^[0-9]+$=i", $number))
 				{
 				return TRUE;
 				}
@@ -85,7 +85,7 @@
 
 
 	// sets smilies
-	if (!function_exists("set_smilies"))
+	if(!function_exists("set_smilies"))
 		{
 		function set_smilies($text)
 			{
@@ -106,7 +106,7 @@
 			for($i = 0; $i < count($smiley); $i++)
 				{
 				// replace smilies in entry
-				if (preg_match("/,/is", $smiley[$i]['replacement'], $treffer))
+				if(preg_match("/,/is", $smiley[$i]['replacement'], $treffer))
 					{
 					$smilies = explode(", ", $smiley[$i]['replacement']);
 					for($e = 0; $e < count($smilies); $e++)
@@ -114,7 +114,7 @@
 						if(($smilies[$e] != ":/") AND ($smilies[$e] != "//") AND ($smilies[$e] != "://"))
 							{
 							$smilie_replace[$e] = $text;
-							$smilie_replace[$e] = str_ireplace($smilies[$e], '<img src="images/smilies/'.$smiley[$i]['path'].'" alt="" title="" width="'.$smiley[$i]['width'].'" height="'.$smiley[$i]['height'].'">', $smilie_replace[$e]);
+							$smilie_replace[$e] = str_ireplace($smilies[$e], '<img src="images/smilies/'.$smiley[$i]['path'].'" class="smilies" alt="" title="" width="'.$smiley[$i]['width'].'" height="'.$smiley[$i]['height'].'">', $smilie_replace[$e]);
 							$text = $smilie_replace[$e];
 							}
 						}
@@ -122,7 +122,7 @@
 				if(($smiley[$i]['replacement'] != ":/") AND ($smiley[$i]['replacement'] != "//") AND ($smiley[$i]['replacement'] != "://"))
 					{
 					$smilie_replace[$i] = $text;
-					$smilie_replace[$i] = str_ireplace($smiley[$i]['replacement'], '<img src="images/smilies/'.$smiley[$i]['path'].'" alt="" title="" width="'.$smiley[$i]['width'].'" height="'.$smiley[$i]['height'].'">', $smilie_replace[$i]);
+					$smilie_replace[$i] = str_ireplace($smiley[$i]['replacement'], '<img src="images/smilies/'.$smiley[$i]['path'].'" class="smilies" alt="" title="" width="'.$smiley[$i]['width'].'" height="'.$smiley[$i]['height'].'">', $smilie_replace[$i]);
 					$text = $smilie_replace[$i];
 					}
 				}
@@ -132,7 +132,7 @@
 
 
 	// delete smilies
-	if (!function_exists("delete_smilies"))
+	if(!function_exists("delete_smilies"))
 		{
 		function delete_smilies($text)
 			{
@@ -153,7 +153,7 @@
 			for($i = 0; $i < count($smiley); $i++)
 				{
 				// replace smilies in entry
-				if (preg_match("/,/is", $smiley[$i]['replacement'], $treffer))
+				if(preg_match("/,/is", $smiley[$i]['replacement'], $treffer))
 					{
 					$smilies = explode(", ", $smiley[$i]['replacement']);
 					for($e = 0; $e < count($smilies); $e++)
@@ -180,7 +180,7 @@
 
 	// this function caches images for guestbook entries
 	// (NOT ACTIVE NOW, MAYBE IN 0.7...)
-	if (!function_exists("img_cache"))
+	if(!function_exists("img_cache"))
 		{
 		function img_cache($image, $entry_id)
 			{
@@ -193,19 +193,19 @@
 
 			$fp = fopen("../cache/foo.gif", "wb+");
 			fwrite($fp, $file);
-			fclose($fp); 
+			fclose($fp);
 			}
 		}
 
 
 	// this function adds "http://" to a bbcode url
 	// if it isn't there
-	if (!function_exists("http"))
+	if(!function_exists("http"))
 		{
 		function http($treffer)
 			{
 			$url = $treffer[1];
-			if (!preg_match("/http:\/\//i", $url))
+			if(!preg_match("/http:\/\//i", $url))
 				{
 				$url = "http://".$url;
 				}
@@ -216,7 +216,7 @@
 
 	// this function adds "http://" to a bbcode url
 	// if it isn't there AND checks if there is an image between the [url] bbcode
-	if (!function_exists("http_img"))
+	if(!function_exists("http_img"))
 		{
 		function http_img($treffer)
 			{
@@ -230,10 +230,10 @@
 			@mysql_select_db($db['dbname'], $link) or die ("(functions.inc.php, http_img) Error, cannot select database: ".mysql_error());
 			$result = @mysql_query($sql, $link) or die ("(functions.inc.php, http_img) Error in sql query: ".mysql_error());
 			$settings = @mysql_fetch_array($result);
-			if ($settings['center_img'] == 1) { $center_1 = "<center>"; $center_2 = "</center>"; }
+			if($settings['center_img'] == 1) { $center_1 = "<center>"; $center_2 = "</center>"; }
 
 			// search for missing http://
-			if (!preg_match("/http:\/\//i", $url))
+			if(!preg_match("/http:\/\//i", $url))
 				{
 				$url = "http://".$url;
 				}
@@ -243,7 +243,7 @@
 			if(isset($settings['allow_img_tag']) AND $settings['allow_img_tag'] == 1)
 				{
 				// does [url] contain an image?
-				if (preg_match("/\[img\](.*?)\[\/img\]/is", $text, $image))
+				if(preg_match("/\[img\](.*?)\[\/img\]/is", $text, $image))
 					{
 					$img_url = $image[1];
 					if(function_exists("getimagesize"))
@@ -274,13 +274,13 @@
 						$link = $center_1."<a href='".$url."' target='_blank' title='".$url."'><img class='entry' src='".$img_url."' alt='".$img_url."' title='".$img_url."'></a>".$center_2;
 						}
 					}
-				elseif (preg_match("/\[img=([0-9]+),([0-9]+)\](.*?)\[\/img\]/is", $text, $image))
+				elseif(preg_match("/\[img=([0-9]+),([0-9]+)\](.*?)\[\/img\]/is", $text, $image))
 					{
 					$max_width = $settings['max_img_width'];
 					$max_height = $settings['max_img_height'];
 
-					if ($image[1] > $max_width) { $image_width = $max_width; } else { $image_width = $image[1]; }
-					if ($image[2] > $max_height) { $image_height = $max_height; } else { $image_height = $image[2]; }
+					if($image[1] > $max_width) { $image_width = $max_width; } else { $image_width = $image[1]; }
+					if($image[2] > $max_height) { $image_height = $max_height; } else { $image_height = $image[2]; }
 
 					$link = $center_1."<a href='".$url."' target='_blank' title='".$url."'><img class='entry' src='".$image[3]."' alt='".$image[3]."' title='".$image[3]."' width='".$image_width."' height='".$image_height."'></a>".$center_2;
 					}
@@ -292,7 +292,7 @@
 
 	// this function analyzes the size of the image in the [img]-tag and reduces it's
 	// dimensions to "normal" ones that don't break up the flow of the template design
-	if (!function_exists("img_1"))
+	if(!function_exists("img_1"))
 		{
 		function img_1($treffer)
 			{
@@ -308,7 +308,7 @@
 				{
 				$img_url = $treffer[1];
 				$max_width = $settings['max_img_width'];
-				if ($settings['center_img'] == 1) { $center_1 = "<center>"; $center_2 = "</center>"; }
+				if($settings['center_img'] == 1) { $center_1 = "<center>"; $center_2 = "</center>"; }
 				if(function_exists("getimagesize"))
 					{
 					if($img_size = @getimagesize($img_url))
@@ -347,7 +347,7 @@
 
 	// this functions analyzes the provided size values of the user and
 	// reduces them to "normal" ones if they break up the flow of the template
-	if (!function_exists("img_2"))
+	if(!function_exists("img_2"))
 		{
 		function img_2($treffer)
 			{
@@ -368,9 +368,9 @@
 				$max_width = $settings['max_img_width'];
 				$max_height = $settings['max_img_height'];
 
-				if ($treffer[1] > $max_width) { $image_width = $max_width; } else { $image_width = $treffer[1]; }
-				if ($treffer[2] > $max_height) { $image_height = $max_height; } else { $image_height = $treffer[2]; }
-				if ($settings['center_img'] == 1) { $center_1 = "<center>"; $center_2 = "</center>"; }
+				if($treffer[1] > $max_width) { $image_width = $max_width; } else { $image_width = $treffer[1]; }
+				if($treffer[2] > $max_height) { $image_height = $max_height; } else { $image_height = $treffer[2]; }
+				if($settings['center_img'] == 1) { $center_1 = "<center>"; $center_2 = "</center>"; }
 				$bbcode = $center_1."<img class='entry' src='".$image_url."' alt='".$image_url."' title='".$image_url."' width='".$image_width."' height='".$image_height."'>".$center_2;
 				}
 			else
@@ -382,7 +382,7 @@
 		}
 
 
-	if (!function_exists("quote"))
+	if(!function_exists("quote"))
 		{
 		function quote($treffer)
 			{
@@ -393,7 +393,7 @@
 		}
 
 
-	if (!function_exists("quote_name"))
+	if(!function_exists("quote_name"))
 		{
 		function quote_name($treffer)
 			{
@@ -405,7 +405,7 @@
 		}
 
 
-	if (!function_exists("flash"))
+	if(!function_exists("flash"))
 		{
 		function flash($treffer)
 			{
@@ -426,12 +426,12 @@
 				$max_width = $settings['max_flash_width'];
 				$max_height = $settings['max_flash_height'];
 
-				if ($treffer[1] > $max_width) { $flash_width = $max_width; } else { $flash_width = $treffer[1]; }
-				if ($treffer[2] > $max_height) { $flash_height = $max_height; } else { $flash_height = $treffer[2]; }
+				if($treffer[1] > $max_width) { $flash_width = $max_width; } else { $flash_width = $treffer[1]; }
+				if($treffer[2] > $max_height) { $flash_height = $max_height; } else { $flash_height = $treffer[2]; }
 
 				// simplify youtube urls for the user
-				if (preg_match("/http:\/\/www.youtube.com\/watch\?v\=(.*?)/is", $flash_url, $found)) { $flash_url = preg_replace("/http:\/\/www.youtube.com\/watch\?v=(.*?)/is", "http://www.youtube.com/v/$1", $flash_url); }
-				if ($settings['center_flash'] == 1) { $center_1 = "<center>"; $center_2 = "</center>"; }
+				if(preg_match("/http:\/\/www.youtube.com\/watch\?v\=(.*?)/is", $flash_url, $found)) { $flash_url = preg_replace("/http:\/\/www.youtube.com\/watch\?v=(.*?)/is", "http://www.youtube.com/v/$1", $flash_url); }
+				if($settings['center_flash'] == 1) { $center_1 = "<center>"; $center_2 = "</center>"; }
 				/* $bbcode = $center_1."<iframe width='".$flash_width."' height='".$flash_height."' src='".$flash_url."' frameborder='0'></iframe>".$center_2; //allowfullscreen */
 				// the following html code is taken from phpBB 3.0.9, released under GNU/GPL
 				$bbcode = $center_1."<object classid='clsid:D27CDB6E-AE6D-11CF-96B8-444553540000' codebase='http://active.macromedia.com/flash2/cabs/swflash.cab#version=5,0,0,0' width='".$flash_width."' height='".$flash_height."'>
@@ -454,7 +454,7 @@
 
 
 	// bbcode formatting
-	if (!function_exists("bbcode_format"))
+	if(!function_exists("bbcode_format"))
 		{
 		function bbcode_format($bbcode, $page)
 			{
@@ -533,7 +533,7 @@
 		}
 
 	// deletes bbcode
-	if (!function_exists("bbcode_delete"))
+	if(!function_exists("bbcode_delete"))
 		{
 		function bbcode_delete($bbcode)
 			{
@@ -575,7 +575,7 @@
 		}
 
 	// checks if login is ok
-	if (!function_exists("login_ok"))
+	if(!function_exists("login_ok"))
 		{
 		function login_ok($name, $ID, $password)
 			{
@@ -583,7 +583,7 @@
 
 			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(functions.inc.php, login_ok) Error, cannot connect to database: ".mysql_error());
 			@mysql_select_db($db['dbname'], $link) or die ("(functions.inc.php, login_ok) Error, cannot select database: ".mysql_error());
-			
+
 			if($ID != "")
 				{
 				$sql = "SELECT user_password FROM ".$db['prefix']."user WHERE ID=".$ID;
@@ -597,7 +597,7 @@
 			$user = @mysql_fetch_array($result);
 			$pass = md5($password);
 
-			if ($user['user_password'] == $pass)
+			if($user['user_password'] == $pass)
 				{
 				return TRUE;
 				unset($ID);
@@ -615,7 +615,7 @@
 		}
 
 	// checks if username exists when adding new user
-	if (!function_exists("check_if_user_exists"))
+	if(!function_exists("check_if_user_exists"))
 		{
 		function check_if_user_exists($name, $email)
 			{
@@ -640,7 +640,7 @@
 
 			$sql = "SELECT user_email FROM ".$db['prefix']."user WHERE user_email=".$email;
 			$result = @mysql_query($sql, $link) or die ("(functions.inc.php, check_if_user_exists, email) Error in sql query: ".mysql_error());
-			
+
 			$user = @mysql_fetch_array($result);
 
 			if(secure_value(strtolower($user['user_email'])) == strtolower($email))
@@ -660,8 +660,8 @@
 	// be broken into two or more strings. If $settings['wordwrap'] == 0, function is off.
 	// This method taken from http://de.php.net/manual/en/function.wordwrap.php#64517
 	// by ab_at_notenet(dot)dk (thanks for that!!) will luckily not affect html tags
-	if (!function_exists("textWrap"))
-		{	
+	if(!function_exists("textWrap"))
+		{
 		function textWrap($text, $size)
 			{
 			$new_text = '';
@@ -670,13 +670,13 @@
 			for ($i=0; $i<$sizeof; ++$i)
 				{
 				$text_2 = explode('<',$text_1[$i]);
-				if (!empty($text_2[0]))
+				if(!empty($text_2[0]))
 					{
 					$new_text .= preg_replace('#([^\n\r .]{'. $size .'})#i', '\\1  ', $text_2[0]);
 					}
-				if (!empty($text_2[1]))
+				if(!empty($text_2[1]))
 					{
-					$new_text .= '<' . $text_2[1] . '>'; 
+					$new_text .= '<' . $text_2[1] . '>';
 					}
 				}
 			return $new_text;
@@ -684,14 +684,14 @@
 		}
 
 	// secure values to prevent remote sql exploits
-	if (!function_exists("secure_value"))
+	if(!function_exists("secure_value"))
 		{
 		function secure_value($value)
 			{
-			if (get_magic_quotes_gpc()) {
+			if(get_magic_quotes_gpc()) {
 				$value = stripslashes($value);
 				}
-			if (!is_numeric($value)) {
+			if(!is_numeric($value)) {
 				$value = "'" . mysql_real_escape_string($value) . "'";
 				}
 			return $value;
@@ -699,7 +699,7 @@
 		}
 
 	// turn xhtml breaks to new lines
-	if (!function_exists("xhtmlbr2nl"))
+	if(!function_exists("xhtmlbr2nl"))
 		{
 		function xhtmlbr2nl($value)
 			{
@@ -709,7 +709,7 @@
 		}
 
 	// replace placeholders in email
-	if (!function_exists("format_mail"))
+	if(!function_exists("format_mail"))
 		{
 		function format_mail($value, $name, $date, $time, $message, $domain, $url_to_gb, $adduser_name, $adduser_password, $adduser_url, $new_password_key, $user_id, $new_password)
 			{
@@ -731,7 +731,7 @@
 		}
 
 	// replace umlauts in email
-	if (!function_exists("repl_uml"))
+	if(!function_exists("repl_uml"))
 		{
 		function repl_uml($text, $charset)
 			{
@@ -749,18 +749,18 @@
 				$text = preg_replace("/\&ouml;/", "", $text);
 				$text = preg_replace("/\&szlig;/", "", $text);
 				}
-			
+
 			return $text;
 			}
 		}
 
 	// generate captcha
-	if (!function_exists("generate_captcha"))
+	if(!function_exists("generate_captcha"))
 		{
 		function generate_captcha($captcha_method)
 			{
 			require "includes/config.inc.php";
-			if ($captcha_method == 0)
+			if($captcha_method == 0)
 				{
 				$captcha_letters = array("A", "B", "C", "D", "E", "F", "G", "H", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z");
 				$captcha_numbers = array("2", "3", "4", "5", "6", "8", "9");
@@ -770,11 +770,11 @@
 					// if you like to use special characters in your captcha
 					// set the "2" in the following line to "3"
 					$captcha_random = rand(1, 2);
-					if ($captcha_random == 1)
+					if($captcha_random == 1)
 						{
 						$code .= $captcha_letters[rand(0, (count($captcha_letters))-1)];
 						}
-					elseif ($captcha_random == 2)
+					elseif($captcha_random == 2)
 						{
 						$code .= $captcha_numbers[rand(0, (count($captcha_numbers))-1)];
 						}
@@ -785,14 +785,14 @@
 					}
 				$sql = "UPDATE `".$db['prefix']."captcha` SET `code` = '".$code."' LIMIT 1";
 				}
-			elseif ($captcha_method == 1)
+			elseif($captcha_method == 1)
 				{
 				$captcha_rnd_1 = rand(1, 10);
 				$captcha_rnd_2 = rand(1, 20);
 				$captcha_rnd_3 = rand(1, 30);
 
 				$captcha_rnd_method = rand(1, 2);
-				if ($captcha_rnd_method == 1)
+				if($captcha_rnd_method == 1)
 					{
 					$captcha_sum = $captcha_rnd_1 + $captcha_rnd_2;
 					$captcha_math_symbol_1 = "+";
@@ -805,7 +805,7 @@
 				$captcha_sum2 = $captcha_sum; // debug
 
 				$captcha_rnd_method = rand(1, 2);
-				if ($captcha_rnd_method == 1)
+				if($captcha_rnd_method == 1)
 					{
 					$captcha_sum = $captcha_sum + $captcha_rnd_3;
 					$captcha_math_symbol_2 = "+";
@@ -822,7 +822,7 @@
 				$sql = "UPDATE `".$db['prefix']."captcha_math` SET `math` = '".$captcha_math."', `sum` = '".$captcha_sum."' LIMIT 1 ;";
 				}
 
-			if (isset ($captcha_method))
+			if(isset ($captcha_method))
 				{
 				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(functions.inc.php, generate_captcha) Error, line 815: ".mysql_error());
 				@mysql_select_db($db['dbname'], $link) or die ("(functions.inc.php, generate_captcha) Error, line 816: ".mysql_error());
@@ -832,7 +832,7 @@
 		}
 
 	// generate user_key
-	if (!function_exists("generate_key_and_pw"))
+	if(!function_exists("generate_key_and_pw"))
 		{
 		function generate_key_and_pw($name, $length)
 			{
@@ -848,15 +848,15 @@
 				// if you like to use special characters in your user_key
 				// set the "3" in the following line to "4"
 				$key_pw_random = rand(1, 3);
-				if ($key_pw_random == 1)
+				if($key_pw_random == 1)
 					{
 					$key_pw .= $key_pw_letters[rand(0, (count($key_pw_letters))-1)];
 					}
-				elseif ($key_pw_random == 2)
+				elseif($key_pw_random == 2)
 					{
 					$key_pw .= $key_pw_letters_small[rand(0, (count($key_pw_letters_small))-1)];
 					}
-				elseif ($key_pw_random == 3)
+				elseif($key_pw_random == 3)
 					{
 					$key_pw .= $key_pw_numbers[rand(0, (count($key_pw_numbers))-1)];
 					}
@@ -881,9 +881,9 @@
 		}
 
 	// check $_SESSION['key'}
-	if (!function_exists("check_session"))
+	if(!function_exists("check_session"))
 		{
-		function check_session($sessid, $sessionkey, $timeout)
+		function check_session($sessid, $sessionkey, $sessionip, $timeout)
 			{
 			require "../includes/config.inc.php";
 
@@ -895,40 +895,43 @@
 
 			$user = @mysql_fetch_array($result);
 
+			$count_ok = 0;
+
+			if($sessionip == $_SERVER['REMOTE_ADDR'])
+				{
+				$count_ok++; // 1
+				}
+
 			if($user['user_key'] == $sessionkey)
 				{
-				$ok = 1;
+				$count_ok++; // 2
 				}
-			
-			if(time() > ($user['logged_in'] + $timeout))
-				{
-				$ok = 0;
-				}
-			else
+
+			if(time() < ($user['logged_in'] + $timeout))
 				{
 				$sql = "UPDATE ".$db['prefix']."user SET `logged_in` = '".time()."' WHERE ID=".$sessid." LIMIT 1";
 				@mysql_query($sql, $link) or die ("(functions.inc.php, check_session, update) Error in sql query: ".mysql_error());
-				$ok = 1;
+				$count_ok++; // 3
 				}
-			
-			if($ok == 1) { return TRUE; } else { return FALSE; }
+
+			if($count_ok == 3) { return TRUE; } else { return FALSE; }
 			}
 		}
 
 	// check rights for access of several adminsites
-	if (!function_exists("check_rights"))
+	if(!function_exists("check_rights"))
 		{
 		function check_rights($site, $sessid)
 			{
 			require "../includes/config.inc.php";
-			
+
 			$sql = "SELECT user_level, r_settings, r_activate, r_deactivate, r_delete, r_edit, r_spam, r_edit_smilies FROM ".$db['prefix']."user WHERE ID=".$sessid;
 			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(functions.inc.php, check_rights) Error, cannot connect to database: ".mysql_error());
 			@mysql_select_db($db['dbname'], $link) or die ("(functions.inc.php, check_rights) Error, cannot select database: ".mysql_error());
 			$result = @mysql_query($sql, $link) or die ("(functions.inc.php, check_rights) Error in sql query: ".mysql_error());
 
 			$user = @mysql_fetch_array($result);
-			
+
 			switch ($user['user_level'])
 				{
 				case 0:
@@ -981,7 +984,7 @@
 		}
 
 	// clean string
-	if (!function_exists("cleanstr"))
+	if(!function_exists("cleanstr"))
 		{
 		function cleanstr($string)
 			{
@@ -991,7 +994,7 @@
 		}
 
 	// get version info with cURL
-	if (!function_exists("get_mgb_version_info"))
+	if(!function_exists("get_mgb_version_info"))
 		{
 		function get_mgb_version_info($url)
 			{
@@ -1009,7 +1012,7 @@
 		}
 
 	// replace template placeholders
-	if (!function_exists("template"))
+	if(!function_exists("template"))
 		{
 		function template($placeholder, $data, $content)
 			{
