@@ -1,8 +1,8 @@
 <?php
 	/*
-	MGB 0.6 - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
-	
+	MGB 0.6.x - OpenSource PHP and MySql Guestbook
+	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/
+
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
 	the Free Software Foundation; either version 2 of the License, or
@@ -18,17 +18,19 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// =============================== //
-	// lang_settings.php - English 1.3 //
-	// =============================== //
-	//
-	// This languagefile was translated by Christian Rech alias HeyJ (mail@heyj.de) 
-	// and edited by Jürgen Schäfer ==> juergen.schaefer(at)minetoshsoft.com
-	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
+	// ======================
+	// settings.php - English
+	// ======================
 
-// general settings
+	// This languagefile was translated by Christian Rech alias HeyJ (mail@heyj.de)
+	// and edited by Jürgen Schäfer ==> juergen.schaefer(at)minetoshsoft.com
+	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+
+	// general settings
 	$charset = "utf-8";
 	$language = "English";
 	$language_short = "en";
-	$language_version = "1.3";
+	$language_version = "1.5.1";
+	$language_timezone = "Europe/London";
+	$language_author = "J&uuml;rgen Sch&auml;fer";
 ?>
