@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -18,17 +18,19 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-// =========================== //
-// settings.php - Français 1.0 //
-// =========================== //
+	// =====================
+	// settings.php - French
+	// =====================
 
-// Français formel (Vous) //
-// This language file was translated by Jürgen Schäfer, 2010; ==> http://www.minetoshsoft.com // 
-// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
+	// Français formel (Vous)
+	// This language file was translated by Jürgen Schäfer, 2010; ==> http://www.minetoshsoft.com
+	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
-// general settings
+	// general settings
 	$charset = "utf-8";
-	$language = "French / Français (Vous)";
+	$language = "Français (Vous) / French (formal)";
 	$language_short = "fr";
-	$language_version = "1.2";
+	$language_version = "1.5.1";
+	$language_timezone = "Europe/Paris";
+	$language_author = "J&uuml;rgen Sch&auml;fer";
 ?>
