@@ -1,8 +1,7 @@
 <?php
-	
 	/*
-	MGB 0.6 - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
+	MGB 0.6.x - OpenSource PHP and MySql Guestbook
+	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -19,17 +18,18 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// ========================== //
-	// settings.php - Italian 1.2 //
-	// ========================== //
-	//
-	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com) 
-	//
-	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
+	// ======================
+	// settings.php - Italian
+	// ======================
+
+	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com)
+	// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 	// general settings
 	$charset = "utf-8";
-	$language = "Italian / Italiano";
+	$language = "Italiano / Italian";
 	$language_short = "it";
-	$language_version = "1.2";
+	$language_version = "1.4.1";
+	$language_timezone = "Europe/Rome";
+	$language_author = "Christian Castelli";
 ?>
