@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -18,11 +18,12 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// ============================================== //
-	// lang_admin.php - Turkish 1.1 by Mustafa Dündar //
-	// ============================================== //
-	//
-	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
+	// ========================
+	// lang_admin.php - Turkish
+	// ========================
+
+	// Translated by Mustafa Dündar
+	// ++++++++++++++++++++++++++++
 
 	// general values
 	$lang['no'] = "Hayýr";
@@ -32,8 +33,18 @@
 	$lang['save'] = "Kaydet";
 	$lang['administrator'] = "Yönetici";
 	$lang['moderator'] = "Moderatör";
+	$lang['gravatar_type_0'] = "Standard";
+	$lang['gravatar_type_1'] = "Mistery-Man";
+	$lang['gravatar_type_2'] = "Identicon";
+	$lang['gravatar_type_3'] = "Monsterid";
+	$lang['gravatar_type_4'] = "Wavatar";
+	$lang['gravatar_type_5'] = "Retro";
+	$lang['gravatar_position_left'] = "Left side of entry";
+	$lang['gravatar_position_right'] = "Right side of entry";
+	$lang['timestamp'] = "Timestamp";
+	$lang['quote'] = "Quote of";
 
-	// login.php
+	// login.inc.php
 	$lang['title'] = "MGB {MGB_VERSION} - Yönetimi";
 	$lang['login_username'] = "Kullanýcý adý:";
 	$lang['login_password'] = "Þifre:";
@@ -60,7 +71,8 @@
 	$lang['errormessage12'] = "Bu anahtar geçersiz veya süresi dolmuþtur.";
 	$lang['errormessage13'] = "Kullanýcý Hesabýnýz için yeni Þifre talep edilmiþtir.<br>Yeni bir Þifre Talebi, yenisi aktiv olana kadar veya süresi bitene kadar mümkün deðildir.";
 	$lang['errormessage14'] = "e-Posta gönderilemedi. Posta sunucusu ile ilgili bir sorun olabilir.";
-	$lang['errormessage15'] = "Sürümü tespit edilemedi, çünki <a href=\"http://php.net/manual/de/function.fopen.php\">fopen()</a> sunucu devredýþý býrakýlmýþtýr.<br>Setze Dich gegebenenfalls mit Deinem Hoster in Verbindung.<br><br>Bu zaman içinde en son sürümü hakkýnda http://www.m-gb.org/ den bilgi alabilirsin.";
+	$lang['errormessage15'] = "Sürümü tespit edilemedi, çünki <a href=\"http://php.net/manual/tr/function.fopen.php\">fopen()</a> sunucu devredýþý býrakýlmýþtýr.<br>Setze Dich gegebenenfalls mit Deinem Hoster in Verbindung.<br><br>Bu zaman içinde en son sürümü hakkýnda http://www.m-gb.org/ den bilgi alabilirsin.";
+	$lang['errormessage16'] = "Your new password is too short. Secure passwords should have at least ".$settings['password_min_length']." characters.";
 
 	// general strings
 	$lang['back_to_mainpage'] = "Geri Anasayfa";
@@ -105,11 +117,13 @@
 	$lang['sendmail_user_comment_title'] = "Senin Kayýtýna {DOMAIN} Yorum yapýlmýþtýr";
 	$lang['sendmail_adduser_title'] = "Kullanýcý verileri {DOMAIN}";
 	$lang['sendmail_adduser_text'] = "Kullanýcý verileri Yönetici tarafýndan {DOMAIN} de giriþ yapýlmýþtýr. Burada Kullnýcý verileri:<br /><br />Kullanýcý adý: {ADDUSER_NAME}<br />Þifre: {ADDUSER_PASSWORD}<br /><br />Sen buraya giriþ yapabilirsin: {ADDUSER_URL}";
-	$lang['sendmail_admin_text'] = "{NAME} Ziyaretci Defterinde yeni bir Kayýt býrakmýþtýr.<br /><br />Tarih: {DATE}<br />Zaman: {TIME}<br /><br />---<br />{MESSAGE}<br />---";
-	$lang['sendmail_user_text'] = "Merhaba {NAME},<br /><br />Ziyaaretci Defterinindeki Kayýt için çok Teþekkür ederim. Kayýt kýsa bir süre incelemeden sonra serbest býrakýlacaktýr.";
+	$lang['sendmail_admin_text'] = "{NAME} Ziyaretci Defterinde yeni bir Kayýt býrakmýþtýr.<br /><br />Tarih: {DATE}<br />Zaman: {TIME}<br /><br />---<br />{MESSAGE}<br />---<br /><br />{URL_TO_GB}";
+	$lang['sendmail_user_text'] = "Merhaba {NAME},<br /><br />Ziyaaretci Defterinindeki Kayýt için çok Teþekkür ederim.";
+	$lang['sendmail_user_text_moderated'] = "Merhaba {NAME},<br /><br />Ziyaaretci Defterinindeki Kayýt için çok Teþekkür ederim. Kayýt kýsa bir süre incelemeden sonra serbest býrakýlacaktýr.";
 	$lang['sendmail_user_notification_text'] = "Merhaba {NAME},<br /><br />{DOMAIN} Kayýtýnýz biraz önce etkinleþmiþtir. Siz onu burada görebilirsiniz: {URL_TO_GB}";
 	$lang['sendmail_comment_text'] = "Merhaba {NAME},<br /><br />Kayýtýna<br /><br />---<br />{MESSAGE}<br />---<br /><br />biraz önce Yorum yapýlmýþtýr. Siz onu burada görebilirsiniz: {URL_TO_GB}";
 	$lang['sendmail_contactmail_text'] = "Ziyaretçi Defterine {DOMAIN}, {NAME} den e-Posta aldýnýz. Haber:<br /><br />---<br />{MESSAGE}<br />---<br /><br />Tarih: {DATE}<br />Zaman: {TIME}";
+	$lang['sendmail_contactmail_text_copy'] = "You sent an email to {NAME} through the guestbook of {DOMAIN}. Here\'s a copy of the message:<br /><br />---<br />{MESSAGE}<br />---<br /><br />Date: {DATE}<br />Time: {TIME}";
 	$lang['sendmail_new_password_title'] = "Yeni Þifre: onay";
 	$lang['sendmail_new_password_text'] = "Merhaba {NAME},<br /><br />Hesabýnýz için yeni bir Þifre oluþturulmuþtur. Bunu doðrulamak için 24 saat içinde aþaðýdaki linki týklayýnýz. Yeni Þifre aktifleþinceye kadar eski Þifre aktif kalacaktýr.<br /><br />24 saat içinde link e basýlmaz ise, yeni Þifre devreye girmez.<br /><br />{NEW_PASSWORD_LINK}";
 	$lang['sendmail_new_password_created_title'] = "Yeni Þifre aktifleþti";
@@ -130,11 +144,14 @@
 	$lang['bugreport'] = "Hata bildirmek";
 	$lang['version'] = "Versiyon";
 	$lang['manual'] = "Belge";
+	$lang['to_guestbook'] = "Ziyaretçi Defteri kaydol";
 	$lang['paypal'] = "Eðer MGB yararlý bulursanýz, geliþimesini desteklemek isterseniz, baðýþ için çekinmeyin.";
 
 	// settings.inc.php
 	$lang['edit_caption_general'] = "Genel Ayarlar";
 	$lang['edit_caption_look'] = "Görünüm";
+	$lang['edit_caption_bbcodes'] = "BBCodes";
+	$lang['edit_caption_smilies'] = "Emoticons";
 	$lang['edit_caption_gravatars'] = "Gravatar desteði";
 	$lang['edit_caption_security'] = "Güvenlik";
 	$lang['edit_caption_email'] = "e-Posta";
@@ -145,24 +162,41 @@
 	$lang['edit_gb_path'] = "Ziyaretçi Defteri Yol:";
 	$lang['edit_h_keywords'] = "Anahtar Kelimeler:";
 	$lang['edit_h_description'] = "Açýklama:";
+	$lang['edit_timezone'] = "Timezone:";
 	$lang['edit_admin_name'] = "Admin Adý:";
 	$lang['edit_admin_email'] = "Admin e-Posta:";
 	$lang['edit_admin_gbemail'] = "Ziyaretçi Defteri e-Posta:";
 	$lang['edit_sendmail_admin'] = "e-Posta Uyarýlarý:";
 	$lang['edit_sendmail_admin_text'] = "e-Posta Uyarýlarý için Metin:";
 	$lang['edit_sendmail_user'] = "Kullanýcýlara Teþekkür e-Postasý:";
-	$lang['edit_sendmail_user_text'] = "Teþekkür e-Postasý Metini:";
+	$lang['edit_sendmail_user_text'] = "Teþekkür e-Postasý Metini (not moderated):";
+	$lang['edit_sendmail_user_text'] = "Teþekkür e-Postasý Metini (moderated):";
 	$lang['edit_sendmail_user_notification_text'] = "Aktivasyon e-Posta Metini:";
 	$lang['edit_sendmail_comment_text'] = "Yorum Bildirimi Metini:";
 	$lang['edit_sendmail_contactmail_text'] = "Ziyaretçi Defteri e-Posta Metini:";
+	$lang['edit_sendmail_contactmail_text_copy'] = "Text for a copy of an eMail through the guestbook:";
 	$lang['edit_template_path'] = "Þablon:";
 	$lang['edit_template_style_path'] = "Þablon-Tarzý:";
 	$lang['edit_iconset_path'] = "Grafik Seti:";
 	$lang['edit_language_path'] = "Dil Dosyasý:";
 	$lang['edit_badwords'] = "Sözcük sansür:";
 	$lang['edit_bbcode'] = "Forum Kodlarý:";
+	$lang['edit_allow_img_tag'] = "IMG-Tag:";
+	$lang['edit_max_img_width'] = "Maximum width of image:";
+	$lang['edit_max_img_height'] = "Maximum height of image:";
+	$lang['edit_center_img'] = "Display images centered:";
+	$lang['edit_allow_flash_tag'] = "FLASH-Tag:";
+	$lang['edit_max_flash_width'] = "Maximum width of flash:";
+	$lang['edit_max_flash_height'] = "Maximum height of flash:";
+	$lang['edit_center_flash'] = "Display flash centered:";
 	$lang['edit_smileys'] = "Smilies:";
+	$lang['edit_smileys_break'] = "Smiley line break:";
+	$lang['edit_smileys_order'] = "Sorting of smilies:";
 	$lang['edit_captcha'] = "Güvenlik sorusu (''Captcha''):";
+	$lang['edit_captcha_method'] = "Sort of captcha:";
+	$lang['edit_captcha_coords'] = "Captcha coordinates:";
+	$lang['edit_captcha_color'] = "Captcha text color:";
+	$lang['edit_captcha_angle'] = "Captcha angle:";
 	$lang['edit_akismet_plugin'] = "Akismet-Eklentisi:";
 	$lang['edit_akismet_api'] = "Akismet API Anahtarý (gerekli):";
 	$lang['edit_akismet_mark_as_spam'] = "Spam-İşareti:";
@@ -173,15 +207,22 @@
 	$lang['edit_user_notification'] = "Kullanýcý bildirimi:";
 	$lang['edit_user_show_email'] = "Müþteri Kitabý kullanýcý e-Posta:";
 	$lang['edit_session_timeout'] = "Oturum Sonaerme zamaný:";
+	$lang['edit_password_min_length'] = "Minimum length for passwords:";
 	$lang['edit_moderated'] = "Modernes Müþteri Defteri:";
+	$lang['edit_require_email'] = "eMail required:";
 	$lang['edit_entries_per_page'] = "Sayfa baþýna giriþ adedi:";
 	$lang['edit_entries_order'] = "Numaralandýrma sýrasý:";
+	$lang['edit_entries_order_asc_desc'] = "Sequence of ordering:";
+	$lang['edit_entries_numbering'] = "Sequence of numbering:";
 	$lang['edit_spam_protection'] = "e-Posta Spam korumasý:";
 	$lang['edit_ipblocker'] = "IP-Barikat:";
 	$lang['edit_wordwrap'] = "Satýrsonu:";
 	$lang['edit_dateform'] = "Tarih Biçimi:";
 	$lang['edit_gravatar_show'] = "Gravatars Göster:";
 	$lang['edit_gravatar_rating'] = "Gravatars sýnýflandýrma:";
+	$lang['edit_gravatar_type'] = "Unregistered gravatars:";
+	$lang['edit_gravatar_size'] = "Gravatar size:";
+	$lang['edit_gravatar_position'] = "Position:";
 
 	$lang['edit_expl_title'] = "Müþteri Defteri Baþlýðý.";
 	$lang['edit_expl_h_author'] = "Yazarýn web sitesinin adý.";
@@ -189,29 +230,46 @@
 	$lang['edit_expl_gb_path'] = "Ziyaretçi Defterinin Domain e relatif yolu.";
 	$lang['edit_expl_h_keywords'] = "Anahtar kelimeler virgülle ayrýlacak";
 	$lang['edit_expl_h_description'] = "Sayfanýn kýsa bir açýklamasý.";
+	$lang['edit_expl_timezone'] = "Since PHP5 you must set a timezone. <a href='http://www.php.net/manual/tr/timezones.php' target='_blank'>List of all available timezones</a>.";
 	$lang['edit_expl_admin_name'] = "Admin ismi veya sadece ''Admin''.";
 	$lang['edit_expl_admin_email'] = "Yeni gelen mesajlar bu adresse gönderilecektir.";
 	$lang['edit_expl_admin_gbemail'] = "E-Postalar için gönderici adresi olarak kullanýlýr.";
 	$lang['edit_expl_sendmail_admin'] = "Bu seçenek etkinse, yeni bir kayýt geldiðinde yöneticiye bir e-Posta gönderilir.";
 	$lang['edit_expl_sendmail_admin_text'] = "Bu metin aktif e-Posta bildirimi ile yöneticiye gönderilecektir.<br><br>Mevcut yer tutucularý: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
 	$lang['edit_expl_sendmail_user'] = "Bu seçenek etkinleþtirildiðinde, kullanýcý giriþi için bir teþekkür e-Posta gönderilir.";
-	$lang['edit_expl_sendmail_user_text'] = "Bu Metin kullanýcýya aktýv e-Posta bildirimi gönderilecektir.<br><br>Mevcut yer tutucularý: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
+	$lang['edit_expl_sendmail_user_text'] = "This text will be send to the user, if <b>entry activation is inactive</b> and if the Thank-You mail option is activated.<br><br>Available placeholders: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
+	$lang['edit_expl_sendmail_user_text_moderated'] = "This text will be send to the user, if <b>entry activation is active</b> and if the Thank-You mail option is activated.<br><br>Available placeholders: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
 	$lang['edit_expl_sendmail_user_notification_text'] = "Bu Metin, Kullanýcýya kýsa sürede gönderilen katlýlarý etkinleþirse gönderilir. Ön koþulu kullanýcý olduðunu ve giriþe razý olduðunu bildirmesidir.<br><br>Mevcut yer tutucularý: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
 	$lang['edit_expl_sendmail_comment_text'] = "Eðer Admin veya Moderator tarafýndan bir yorum yapýldýðý taktirde, bu Metin kullanýcýya gönderilir. Ön koþulu kullanýcý olduðunu ve giriþe razý olduðunu bildirmesidir.<br><br>Mevcut yer tutucularý: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
 	$lang['edit_expl_sendmail_contactmail_text'] = "Bu Metin kullanýcýlarýna etkin bir e-Posta Spamkoruma yönünde Ziyaretçi Defteri tarafýndan gelir ise gönderilir.<br><br>Mevcut yer tutucularý: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
+	$lang['edit_expl_sendmail_contactmail_text_copy'] = "This text will be delivered to sender with a copy of his message sent through the guestbook while spam-protection is activated.<br><br>Available placeholders: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
 	$lang['edit_expl_template_path'] = "Kullanýlan Þablon.";
 	$lang['edit_expl_template_style_path'] = "Ýstenýlen Þablon-Stili. Ýlgili Þablon yüklendikten sonra seçilebilir.";
 	$lang['edit_expl_iconset_path'] = "Ýstediðiniz Grafikseti, ikonlar, simgeler ve Captcha Duvarkaðýtlarý ne olursa olsun Þablonu saðlar.";
-	$lang['edit_expl_language_path'] = "Kullanýlan Dil, Özel karekter ile sorunlar için, anahtarý UTF-8 den ISO 8859-15 e(veya tersi) yardýmcý olabilir.";
+	$lang['edit_expl_language_path'] = "<br><b>ATTENTION:</b> Since version <b>0.6.5</b> languages with latin9 (iso-8859-15) code are <b>no longer</b> supported! If you discover problems such as missing variables, empty text fields and so on, please change the language to an utf-8-based one. Also remove every latin9-based languages from your ''language'' folder.<br><br>Afterwards you can solve problems with special chars or umlauts by executing ''convert_ansi.php'' in your ''install'' folder.";
+	$lang['edit_expl_language_charset'] = "Charset:";
 	$lang['edit_expl_badwords'] = "Ziyaretci Defterinde yýldýz tarafýndan deðiþtirilmesi gereken ve istenmeyen kelimeleri virgül ile ayýrarak giriniz. Devre dýþý kalmasý için boþ býrakýnýz.";
 	$lang['edit_expl_bbcode'] = "Metin biçimlendirmesi kullanýcý tarafýndan olabilir.";
+	$lang['edit_expl_allow_img_tag'] = "The implementation of images in a guest-book entry contains some security risks. Images could include malware, or a user could provide an image that is juristic ominous. Many and large pictures also reduce the loading speed of the guest-book.<br><br><b>The IMG-Tag should only be activated if the guest-book is moderated.</b>";
+	$lang['edit_expl_max_img_width'] = "Defines the maximum width of an image.<br><br><b>ATTENTION: This only works if <a href='http://de2.php.net/manual/tr/function.getimagesize.php' target='_blank' title='php.net'>getimagesize();</a> is working, or if width and height are provided with the [img]-Tag like here -> [img=width,height]address of image[/img]).</b>";
+	$lang['edit_expl_max_img_height'] = "Defines the maximum height of an image.<br><br><b>ATTENTION: This only works if <a href='http://de2.php.net/manual/tr/function.getimagesize.php' target='_blank' title='php.net'>getimagesize();</a> is working, or if width and height are provided with the [img]-Tag like here -> [img=width,height]address of image[/img]).</b>";
+	$lang['edit_expl_center_img'] = "Defines if [img]-Tag images are displayed centered.";
+	$lang['edit_expl_allow_flash_tag'] = "Allows the user to insert flash videos, like they come from youtube.<br><br><b>For security reasons the BBCode for flash videos should only be activated if the guestbook is moderated.</b>";
+	$lang['edit_expl_max_flash_width'] = "Defines the maximum widht of a flashvideo.";
+	$lang['edit_expl_max_flash_height'] = "Defines the maximum height of a flashvideo.";
+	$lang['edit_expl_center_flash'] = "Defines if [flash]-Tag videos are displayed centered.";
 	$lang['edit_expl_smileys'] = "Smiles eklemesini kullanýcýya saðlar.";
+	$lang['edit_expl_smileys_break'] = "Defines after how much smilies there is a line break in the list of smilies in ''newentry.php''. Can be very helpful if much smilies are used.";
+	$lang['edit_expl_smileys_order'] = "Indicates how smilies are sorted. Ascending or descending.";
 	$lang['edit_expl_captcha'] = "Bir Kullanýcý yeni bir giriþ ve e-Posta yazý yazmasýný etkinleþtirmesi için bir güvenlik kodu vermesi gerekir.";
 	$lang['edit_expl_captcha_method'] = "Kullanýcý bir aritmetik problemi çözmek için bir güvenlik kodu veya matematiksel bir Captcha arasýnda seçim yapabilirsiniz.";
+	$lang['edit_expl_captcha_coords'] = "Sets the coordinates where the text starts to be drawn into the background picture. Origin is the <b>lower left edge of the first character</b>.";
+	$lang['edit_expl_captcha_color'] = "Sets the text color of the captcha. The value has to be in the HTML-Format and without the number sign '#'.<br><br><b>Right: <span class='newer_version'>505050</span><br>Wrong: <span class='old_version'>#505050</span></b>";
+	$lang['edit_expl_captcha_angle'] = "These values both define the array of degrees, the captcha text is randomly designed with. The left value has to be <b>lower</b> than the right value.";
 	$lang['edit_expl_akismet_plugin'] = "Akismet harici bir hizmettir, yeni giriþlerde spam kontrol eder ve olumlu bir sonuçta giriþi yazar. Akismet eklentisi <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet eklentisi'>http://www.m-gb.org/</a> indirilir.<br><br><b>ATTENTION: With using the plugin 'akismet' you accept the transmission of data to a server in the United States of America. If you don't comply with that circumstance you MUST NOT USE 'Akismet'. Also your users have to agree with that if you activate the plugin.</b>";
+	$lang['edit_expl_akismet_api'] = "Akismet i kullanabilmek için, Akismet-eklentisi <a href='http://akismet.com/signup/#free' title='Akismet API Anahtar'>API Key</a> lazýmdýr. Burada kayýt ver.";
 	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet yüklenmiþtir!</span>";
 	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet yüklenmemiþtir!</span>";
-	$lang['edit_expl_akismet_api'] = "Akismet i kullanabilmek için, Akismet-eklentisi <a href='http://akismet.com/signup/#free' title='Akismet API Anahtar'>API Key</a> lazýmdýr. Burada kayýt ver.";
 	$lang['edit_expl_akismet_mark_as_spam'] = "Bu seçenek aktifse, Akısmet tarfından yeni Spam mesajı olarak tanımlanacak ve Yönetimde Span Katagorisinde görünecektir.";
 	$lang['edit_expl_time_lock'] = "If this option is enabled, a counter that prevents sending the formular too fast runs in the background of a new entry. If the user is too fast with his entry, a message appears that tells him how many seconds he have to wait, until he can sign the guestbook.";
 	$lang['edit_expl_time_lock_value'] = "Minimum time a user has to wait to send the formular.";
@@ -219,17 +277,24 @@
 	$lang['edit_expl_user_notification'] = "Kullanýcýya giriþ mesajý aktive edildiðinde, haberi e-Posta ile mi almasýnýn gerektiðine karar verir.";
 	$lang['edit_expl_user_show_email'] = "Kullanýcýya e-Postanýn Ziyaretçi Defterinde gösterilip gösterilmemesine izin verir.kutusunu devredýþý býrakýrsa, kimse ona eriþemez, Yönetici e-Posta yazabilir";
 	$lang['edit_expl_session_timeout'] = "Kullanýcý verilen zamandan sonra halendaha etkin deðil ise devre dýþý býrakýlýr. Deðer <b>Saniye</b>. Þu Deðerler arasýnda olmadýr >= <b>60</b>.";
+	$lang['edit_expl_password_min_length'] = "Defines the minimum length of passwords for Administrators / Moderators.";
 	$lang['edit_expl_moderated'] = "Ziyaretçi Defterinde giriþlerin görünebilmesi için önceden aktif olarak etkinleþmesi gerekir.";
+	$lang['edit_expl_require_email'] = "If activated, an email address must be provided by the user to post an new entry.<br><br><b>ATTENTION: The use of Akismet overrides this setting.</b>";
 	$lang['edit_expl_entries_per_page'] = "Bir sayfada kaç tane Giriþin görüntüleneceðini gösterir. Deðer <b>0</b> olamaz.";
 	$lang['edit_expl_entries_order'] = "Giriþlerin sayýlý sýrasýnýn nasýl olmasý gerektiðini belirtir.";
+	$lang['edit_expl_entries_order_asc_desc'] = "Defines the sequence in which entries are sorted.";
+	$lang['edit_expl_entries_numbering'] = "Defines the sequence in which entries are numbered.<br><br><b>Attention:</b> This has nothing to do with the sorting of entries. This means just how they are numbered.";
 	$lang['edit_expl_spam_protection'] = "e-Posta ikonunu týklayarak Ýletiþim Formuna katýlým aktýv olduðunda açýlýr ve diðer Kullanýcý e-mail gönderebilir. Böylece e-mail adresi direk olarak <b>gösterilmez</b>.";
 	$lang['edit_expl_ipblocker'] = "Arka arkaya birden fazla giriþi önler.";
 	$lang['edit_expl_wordwrap'] = "Kaç Karakter sayýsýndan sonra, uzun bir kelime, ayrýlmalýdýr. <b>0</b> Deaktivasyon.";
-	$lang['edit_expl_dateform'] = "Göründüðü gibi Tarihi gösterir. Biçimlendirme php funktionu <a class='admin' href='http://www.php.net/manual/en/function.date.php' title='date()' target='_blank'>date()</a> mümkündür.";
+	$lang['edit_expl_dateform'] = "Göründüðü gibi Tarihi gösterir. Biçimlendirme php funktionu <a class='admin' href='http://www.php.net/manual/tr/function.date.php' title='date()' target='_blank'>date()</a> mümkündür.";
 	$lang['edit_expl_gravatar_show'] = "Gravatars (Global Recognized Avatars) kullanýcý giriþi yanýnda görünen küçük resimlerdir. Onlar, Kullanýcý e-Posta adresinde service <a class='admin' href='http://site.gravatar.com' target='_blank' title='Gravatar Service'>kayýtlý</a> iseler, baðlýdýr.";
 	$lang['edit_expl_gravatar_rating'] = "Gravatar larýn hangi sýnýflandýrmaya kadar görüntüleneceðini gösterir.<br><br><b>G</b> = Tüm yaþlar<br><b>PG</b> = hafif Þiddet, kýþkýrtýcý görüntülü Ýnsanlar <br><b>R</b> = Yoðun Þiddet<br><b>X</b> = cinsel resimleri";
+	$lang['edit_expl_gravatar_type'] = "Here you can set how gravatars will be displayed if the users email adress is not registered at the service.";
+	$lang['edit_expl_gravatar_size'] = "Defines the size of the gravatar in <b>pixels</b>.";
+	$lang['edit_expl_gravatar_position'] = "Displays the gravatar on the left or right side of the message.";
 
-	// edit.php
+	// edit.inc.php
 	$lang['ID'] = "ID:";
 	$lang['ip'] = "IP:";
 	$lang['date'] = "Tarih:";
@@ -247,16 +312,16 @@
 	$lang['comment'] = "Yorum:";
 
 	// smilies.inc.php
-	$lang['add_smilies_descr'] = "Here you can edit or remove smilies.<br><br>All smilies have to be in the folder <b>'images/smilies/'</b> in the root directory of the guestbook. You only have to put the filename into the <b>empty textbox</b> and then press <b>save</b>.<br><br><b>Please notice: If you change existing smilies or place holders that were already used in entries, then they cannot be correctly replaced any more! You have to edit these entries by hand.</b>";
+	$lang['add_smilies_descr'] = "Here you can edit, add or remove smilies.<br><br>All smilies need to be in the folder <b>'images/smilies/'</b> in the root directory of the guest book. You only need to put the filename into the <b>empty text-field</b> and then press <b>Save</b>.<br><br>You may also add several placeholders. Separate each of them with <b>a comma and a space</b>. To add smileys in ''newentry.php'', the first of the given placeholders will be used.<br><br><span class='same_version'>Right:</span> :smile:, :), :-)<br><span class='old_version'>Wrong:</span> :smile:,:),:-)<br><br><b>Please note: If you change or delete existing smilies or placeholders already used in entries, they won't be displayed correctly anymore! You will have to edit these entries by hand.</b>";
 	$lang['smiley_path'] = "Filename";
-	$lang['smiley_replacement'] = "Place holder";
+	$lang['smiley_replacement'] = "Placeholder";
 	$lang['add_new_smiley'] = "Add smiley";
+	$lang['checked_smilies'] = "Checked smilies ...";
 	$lang['delete_checked_smilies'] = "... remove from list, keep unchecked";
 	$lang['keep_checked_smilies'] = "... keep, remove unchecked";
 	$lang['smiley_width'] = "Width";
 	$lang['smiley_height'] = "Height";
 	$lang['smilies'] = "Smilies";
-	$lang['checked_smilies'] = "Checked smilies ...";
 
 	// edit_user.inc.php
 	$lang['user_is_active'] = "Kullanýcý aktif:";
@@ -285,7 +350,7 @@
 	$lang['current_version'] = "Yüklü sürüm:";
 	$lang['stable_version'] = "En son kararlý sürüm:";
 	$lang['unstable_version'] = "Son kararsýz sürüm:";
-	$lang['old_version'] = "Sürümün eski.<br>Bir güncelleþtirme önerilir.<br><br><a href='http://www.m-gb.org/index.php?kat=5' class='admin' target='_blank' title='Þimdi güncelleþtir'>En son sürüm için</a>";
+	$lang['old_version'] = "Sürümün eski.<br>Bir güncelleþtirme önerilir.<br><br><a href='http://www.m-gb.org/index.php?id=download_gb' class='admin' target='_blank' title='Þimdi güncelleþtir'>En son sürüm için</a>";
 	$lang['same_version'] = "En son sürüme sahipsin.<br>Bir güncelleþtirme gerekli deðildir.";
 	$lang['newer_version'] = "Mevcut sürüm kararlý sürümden daha yeni.<br>Bir güncelleþtirme gerekli deðildir.";
 	$lang['new_version_available'] = "Daha yeni bir sürüm mevcuttur: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Şimdi yenileyiniz'>{LATEST_VERSION}</a>";
@@ -294,5 +359,7 @@
 	$lang['lostpassword_mail'] = "Senin e-Posta adressin:";
 	$lang['get_new_pw'] = "Yeni Þifre iste";
 	$lang['lostpassword_success'] = "Ýsteðiniz düzenlenmiþtir. Kýsa zamanda bir e-Posta ile <br>onaylink alacaksýnýz. Ona yeni Þifrenizi etkinleþtirmek için týklayýnýz.";
+	$lang['lostpassword_no_success'] = "Your demand couldn't be treated successfully. There was an error with the mailserver.";
 	$lang['lostpassword_success_created'] = "Senin giriþ bilgilerin<br>sana e-Posta ile gönderilmiþtir.";
+	$lang['lostpassword_no_success_created'] = "Your demand couldn't be treated successfully. There was an error with the mailserver.";
 ?>
