@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
 
 	// make sure nobody has direct acces to this script
-	if (!defined('ADMINISTRATION'))
+	if(!defined('ADMINISTRATION'))
 		{
 		include ("error.html");
 		die();
@@ -67,18 +67,19 @@
 						{
 						$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(login.inc.php) Error, line 68: ".mysql_error());
 						@mysql_select_db($db['dbname'], $link) or die ("(login.inc.php) Error, line 69: ".mysql_error());
-						
+
 						generate_key_and_pw($_POST['username'], 16);
-						
+
 						$sql = "SELECT ID, user_name, user_key, user_is_active, logged_out FROM ".$db['prefix']."user WHERE user_name=".$_POST['username'];
 						$result = @mysql_query($sql, $link) or die ("(login.inc.php) Error, line 74: ".mysql_error());
 
 						$user = @mysql_fetch_array($result);
-						
+
 						$_SESSION['ID'] = $user['ID'];
 						$_SESSION['username'] = $user['user_name'];
 						$_SESSION['key'] = $user['user_key'];
 						$_SESSION['user_is_active'] = $user['user_is_active'];
+						$_SESSION['ip'] = $_SERVER['REMOTE_ADDR'];
 
 						if($_SESSION['user_is_active'] == 1)
 							{
@@ -98,7 +99,7 @@
 								$refresh = "<meta http-equiv=\"refresh\" content=\"2; URL=admin.php".$sid."\">";
 								}
 
-							$sql = "UPDATE ".$db['prefix']."user SET `logged_in` = '".time()."', `logged_out` = '0' WHERE ID=".secure_value($user['ID'])." LIMIT 1";
+							$sql = "UPDATE ".$db['prefix']."user SET `logged_in` = '".time()."', `logged_out` = '0', `user_ip` = '".$_SERVER['REMOTE_ADDR']."' WHERE ID=".secure_value($user['ID'])." LIMIT 1";
 							@mysql_query($sql, $link) or die ("(login.inc.php) Error, line 102: ".mysql_error());
 							}
 						else
@@ -146,14 +147,14 @@
 			}
 		}
 
-	if (isset($errorcode) AND $errorcode == 1) { $errormessage = $lang['errormessage1']; }
-	if (isset($errorcode) AND $errorcode == 2) { $errormessage = $lang['errormessage2']; }
-	if (isset($errorcode) AND $errorcode == 3) { $errormessage = $lang['errormessage3']; }
-	if (isset($errorcode) AND $errorcode == 9) { $errormessage = $lang['errormessage9']; }
-	if (isset($errorcode) AND $errorcode == 10) { $errormessage = $lang['errormessage10']; }
-	if (!isset($errorcode)) { $content_errormessage = NULL; };
+	if(isset($errorcode) AND $errorcode == 1) { $errormessage = $lang['errormessage1']; }
+	if(isset($errorcode) AND $errorcode == 2) { $errormessage = $lang['errormessage2']; }
+	if(isset($errorcode) AND $errorcode == 3) { $errormessage = $lang['errormessage3']; }
+	if(isset($errorcode) AND $errorcode == 9) { $errormessage = $lang['errormessage9']; }
+	if(isset($errorcode) AND $errorcode == 10) { $errormessage = $lang['errormessage10']; }
+	if(!isset($errorcode)) { $content_errormessage = NULL; };
 
-	if (isset($login_is_ok) AND $login_is_ok == 1)
+	if(isset($login_is_ok) AND $login_is_ok == 1)
 		{
 		$page_include = $content_login_ok;
 		$page_include = template("TEMPLATE_ERRORMESSAGE", $content_errormessage, $page_include);
@@ -163,7 +164,7 @@
 		}
 	else
 		{
-		$page_include = $content_login;	
+		$page_include = $content_login;
 		if(!isset($errormessage)) { $errormessage = NULL; }
 		$page_include = template("TEMPLATE_ERRORMESSAGE", $content_errormessage, $page_include);
 		$page_include = template("ERRORMESSAGE", $errormessage, $page_include);
