@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 	header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Datum in der Vergangenheit
 
 	// check if MGB has been already installed or updated
-	if (file_exists("includes/config.inc.php"))
+	if(file_exists("includes/config.inc.php"))
 		{
 		require ("includes/config.inc.php");
 		if(!isset($mgb_installation_complete))
@@ -40,7 +40,7 @@
 					<a href=\"install/install.php\">here</a>.<br><br> If MGB is already installed, try to copy your 'config.inc.php' from root directory into 'includes/config.inc.php'.</span>";
 			die();
 			}
-		elseif (isset($mgb_installation_complete) AND $mgb_installation_complete == TRUE AND file_exists('install'))
+		elseif(isset($mgb_installation_complete) AND $mgb_installation_complete == TRUE AND file_exists('install'))
 			{
 			echo "<center><span style='font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; color: darkblue;'>If you upgraded to a newer version shortly, please run
 			<a href='install/upgrade.php'>upgrade.php</a> in install directory <b>now!</b> Otherwise you might discover problems when using this software.<br>If you did a fresh install, you can ignore this message. To remove it, delete install directory. Thank you!<br><br></span></center>";			}
@@ -59,7 +59,7 @@
 	require ("includes/config.inc.php");
 	require ("includes/functions.inc.php");
 	require ("includes/load_settings.inc.php");
-	if (isset($settings['allow_user_change_language']) AND $settings['allow_user_change_language'] == 1)
+	if(isset($settings['allow_user_change_language']) AND $settings['allow_user_change_language'] == 1)
 		{
 		require ("language/".$_POST['user_language']."/lang_main.php");
 		require ("language/".$_POST['user_language']."/settings.php");
@@ -71,7 +71,13 @@
 		}
 	require ("includes/load_templates.inc.php");
 
-	if (isset($settings['time_lock']) AND $settings['time_lock'] == 1)
+	// set timezone
+	if(function_exists("date_default_timezone_set"))
+		{
+		date_default_timezone_set($settings['timezone']);
+		}
+
+	if(isset($settings['time_lock']) AND $settings['time_lock'] == 1)
 		{
 		// start session for anti-spam-time-lock
 		@session_name("time_lock");
@@ -80,9 +86,9 @@
 		@session_regenerate_id();
 
 		// set start time
-		if (isset($_SESSION['start_time']))
+		if(isset($_SESSION['start_time']))
 			{
-			if (time() > ($_SESSION['start_time'] + $settings['time_lock_maxtime']))
+			if(time() > ($_SESSION['start_time'] + $settings['time_lock_maxtime']))
 				{
 				$_SESSION['start_time'] = time();
 				}
@@ -93,15 +99,21 @@
 			}
 		}
 
-	if (isset($_POST['send']) AND $_POST['send'] == $lang['send'])
+	// if akismet is active, override $settings['require_email']
+	if(file_exists("plugins/akismet/akismet.class.php") AND (isset($settings['akismet_api'])) AND ($settings['akismet_api'] != ""))
 		{
-		if (isset($settings['time_lock']) AND $settings['time_lock'] == 1)
+		$settings['require_email'] = 1;
+		}
+
+	if(isset($_POST['send']) AND $_POST['send'] == $lang['send'])
+		{
+		if(isset($settings['time_lock']) AND $settings['time_lock'] == 1)
 			{
 			// time check for formular load
 			$actual_time = time();
 			$difference = $actual_time - $_SESSION['start_time'];
 
-			if ($difference < $settings['time_lock_value'])
+			if($difference < $settings['time_lock_value'])
 				{
 				$errorcode = 10;
 				$rest = $settings['time_lock_value'] - $difference;
@@ -109,24 +121,12 @@
 			}
 
 		// delete html, php code and white spaces
-		
+
 		if(!isset($_POST['user_notification'])) { $_POST['user_notification'] = 0; }
 		if(!isset($_POST['user_show_email'])) { $_POST['user_show_email'] = 0; }
 
-		$_POST['name'] = cleanstr($_POST['name']);
-		$_POST['city'] = cleanstr($_POST['city']);
-		$_POST['message'] = cleanstr($_POST['message']);
-		$_POST['email'] = cleanstr($_POST['email']);
-		$_POST['icq'] = cleanstr($_POST['icq']);
-		$_POST['aim'] = cleanstr($_POST['aim']);
-		$_POST['msn'] = cleanstr($_POST['msn']);
-		$_POST['hp'] = cleanstr($_POST['hp']);
-		$_POST['user_notification'] = cleanstr($_POST['user_notification']);
-		$_POST['user_show_email'] = cleanstr($_POST['user_show_email']);
-		$_POST['user_accept_akismet_service'] = cleanstr($_POST['user_accept_akismet_service']);
-
 		// include akismet if it exists
-		if (file_exists("plugins/akismet/akismet.class.php") AND (isset($settings['akismet_api'])) AND ($settings['akismet_api'] != "") AND (isset($_POST['user_accept_akismet_service']) AND $_POST['user_accept_akismet_service'] == 1) AND ($_POST['name'] != "") AND ($_POST['email'] != "") AND ($_POST['message'] != ""))
+		if(file_exists("plugins/akismet/akismet.class.php") AND (isset($settings['akismet_api'])) AND ($settings['akismet_api'] != "") AND (isset($_POST['user_accept_akismet_service']) AND $_POST['user_accept_akismet_service'] == 1) AND ($_POST['name'] != "") AND ($_POST['email'] != "") AND ($_POST['message'] != ""))
 			{
 			include ("plugins/akismet/akismet.class.php");
 
@@ -169,10 +169,10 @@
 			else
 				{
 				// No errors, check for spam.
-				if ($akismet->isSpam())
+				if($akismet->isSpam())
 					{
 					// if is set in the admin panel, mark the entry as spam
-					if (isset($settings['akismet_mark_as_spam']) AND ($settings['akismet_mark_as_spam'] == 1))
+					if(isset($settings['akismet_mark_as_spam']) AND ($settings['akismet_mark_as_spam'] == 1))
 						{
 						$mark_as_spam = 1;
 						$noemail = 1;
@@ -193,10 +193,10 @@
 		$searchstring = "Hi there, very nice homepage :-)";
 		$pos = strpos($string, $searchstring);
 
-		if ($pos !== false)
+		if($pos !== false)
 			{
 			// if is set in the admin panel, mark the entry as spam
-			if (isset($settings['akismet_mark_as_spam']) AND ($settings['akismet_mark_as_spam'] == 1))
+			if(isset($settings['akismet_mark_as_spam']) AND ($settings['akismet_mark_as_spam'] == 1))
 				{
 				$mark_as_spam = 1;
 				$noemail = 1;
@@ -207,7 +207,7 @@
 				$noemail = 0;
 				}
 			}
-	
+
 		// following IP adresses will be blocked. Add desired IPs to the array.
 		// NOTE: the last entry has to be without a comma at the end like here:
 		//
@@ -226,10 +226,10 @@
 
 		 foreach ($blocked_ips as $ip)
 			{
-			if ($_SERVER["REMOTE_ADDR"] == $ip)
+			if($_SERVER["REMOTE_ADDR"] == $ip)
 				{
 				// if is set in the admin panel, mark the entry as spam
-				if (isset($settings['akismet_mark_as_spam']) AND ($settings['akismet_mark_as_spam'] == 1))
+				if(isset($settings['akismet_mark_as_spam']) AND ($settings['akismet_mark_as_spam'] == 1))
 					{
 					$mark_as_spam = 1;
 					$noemail = 1;
@@ -244,9 +244,9 @@
 
 		// form was sent and is ok!
 		// check if captcha is correct
-		if ($settings['captcha'] == 1)
+		if($settings['captcha'] == 1)
 			{
-			if ($settings['captcha_method'] == 0)
+			if($settings['captcha_method'] == 0) // security code
 				{
 				$sql = "SELECT `code` FROM ".$db['prefix']."captcha LIMIT 1";
 				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 253: ".mysql_error());
@@ -256,9 +256,9 @@
 				$saved_code = @mysql_fetch_array($result);
 				$captcha_code = $saved_code['code'];
 
-				if ($captcha_code != $_POST['captcha']) { $errorcode = 7; }
+				if($captcha_code != $_POST['captcha']) { $errorcode = 7; }
 				}
-			elseif ($settings['captcha_method'] == 1)
+			elseif($settings['captcha_method'] == 1) // mathematical captcha
 				{
 				$sql = "SELECT `sum` FROM ".$db['prefix']."captcha_math LIMIT 1";
 				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 265: ".mysql_error());
@@ -268,35 +268,52 @@
 				$saved_code = @mysql_fetch_array($result);
 				$captcha_code = $saved_code['sum'];
 
-				if ($captcha_code != $_POST['captcha']) { $errorcode = 7; }
+				if($captcha_code != $_POST['captcha']) { $errorcode = 7; }
 				}
 			}
 
-		// if you want the email field to be not necessary, just outcomment next line with "//"
-		if (!check_mail($_POST['email'])) { $errorcode = 4; }
-
-		if ($_POST['icq'])
+		if($_POST['icq'])
 			{
-			if (!check_number($_POST['icq'])) { $errorcode = 5; }
+			if(!check_number($_POST['icq'])) { $errorcode = 5; } // icq# is not valid
 			}
 
-		if (!preg_match("/http:\/\//i", $_POST['hp']))
+		if(!preg_match("/http:\/\//i", $_POST['hp'])) // if http:// is not set, do it
 			{
 			$_POST['hp'] = "http://".$_POST['hp'];
 			}
 
 		// check necessary fields
-		if (!$_POST['message']) { $errorcode = 1; }
-		// if you want the email field to be not necessary, just outcomment next line with "//"
-		if (!$_POST['email']) { $errorcode = 2; }
-		if (!$_POST['name']) { $errorcode = 3; }
-		if ((isset($settings['akismet_plugin'])) AND ($settings['akismet_plugin'] == 1) AND $_POST['user_accept_akismet_service'] != 1) { $errorcode = 11; }
-		
-		// uncomment this to block ip-adresses
-		//if ($_SERVER["REMOTE_ADDR"] == "XXx.xxx.xxx.xxx") { die(); }
-		
-		if (!isset($errorcode))
+		if(!$_POST['message']) { $errorcode = 1; } // message is necessary
+		if(!$_POST['email'])
 			{
+			if($settings['require_email'] == 1)
+				{
+				$errorcode = 2; // email is necessary
+				}
+			}
+		elseif(!empty($_POST['email']))
+			{
+			if(!check_mail($_POST['email'])) { $errorcode = 4; } // no valid email
+			}
+		if(!$_POST['name']) { $errorcode = 3; } // name is necessary
+		if((isset($settings['akismet_plugin'])) AND ($settings['akismet_plugin'] == 1) AND $_POST['user_accept_akismet_service'] != 1) { $errorcode = 11; } // akismet agreement has not been accepted
+
+		if(!isset($errorcode)) // everything's ok, let's format and save the entry
+			{
+			$_POST['email_name'] = $_POST['name'];
+			$_POST['name'] = cleanstr($_POST['name']);
+			$_POST['city'] = cleanstr($_POST['city']);
+			$_POST['email_message'] = $_POST['message'];
+			$_POST['message'] = cleanstr($_POST['message']);
+			$_POST['email'] = cleanstr($_POST['email']);
+			$_POST['icq'] = cleanstr($_POST['icq']);
+			$_POST['aim'] = cleanstr($_POST['aim']);
+			$_POST['msn'] = cleanstr($_POST['msn']);
+			$_POST['hp'] = cleanstr($_POST['hp']);
+			$_POST['user_notification'] = cleanstr($_POST['user_notification']);
+			$_POST['user_show_email'] = cleanstr($_POST['user_show_email']);
+			$_POST['user_accept_akismet_service'] = cleanstr($_POST['user_accept_akismet_service']);
+
 			// delete bbcode except from message
 			$_POST['name'] = bbcode_delete($_POST['name']);
 			$_POST['city'] = bbcode_delete($_POST['city']);
@@ -305,16 +322,16 @@
 			$_POST['hp'] = bbcode_delete($_POST['hp']);
 
 			$_POST['message'] = nl2br($_POST['message']);
-			$t1 = chr(10);
-			$t2 = chr(13);
+			$t1 = chr(10); // new line
+			$t2 = chr(13); // carriage return
 			$_POST['message'] = str_replace($t1,'', $_POST['message']);
 			$_POST['message'] = str_replace($t2,'', $_POST['message']);
-			if ($_POST['hp'] == "http://"){ $_POST['hp'] = ""; }
+			if($_POST['hp'] == "http://"){ $_POST['hp'] = ""; }
 
 			// check if "moderated gb" and "user email notification" is on
-			if (($settings['moderated'] == 1) OR ($mark_as_spam == 1)) { $checked = 0; } else { $checked = 1; }
-			if ($settings['user_notification'] == 0 OR empty($_POST['email'])) { $_POST['user_notification'] = 0; }
-			if ($settings['user_show_email'] == 0 OR empty($_POST['email'])) { $_POST['user_show_email'] = 0; }
+			if(($settings['moderated'] == 1) OR ($mark_as_spam == 1)) { $checked = 0; } else { $checked = 1; }
+			if($settings['user_notification'] == 0 OR empty($_POST['email'])) { $_POST['user_notification'] = 0; }
+			if($settings['user_show_email'] == 0 OR empty($_POST['email'])) { $_POST['user_show_email'] = 0; }
 
 			// get IP of user
 			$ip = $_SERVER["REMOTE_ADDR"];
@@ -354,7 +371,7 @@
 								'".$checked."',
 								'".$mark_as_spam."'
 							   )";
-			
+
 			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 359: ".mysql_error());
 			@mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 360: ".mysql_error());
 			@mysql_query($sql, $link) or die ("(newentry.php) Error, line 361: ".mysql_error());
@@ -364,25 +381,27 @@
 			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 365: ".mysql_error());
 			@mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 366: ".mysql_error());
 			@mysql_query($sql, $link) or die ("(newentry.php) Error, line 367: ".mysql_error());
-			
+
 			// turn xhtml breaks into new lines
 			$_POST['message'] = xhtmlbr2nl($_POST['message']);
-			
+
 			// send an email to admin
 			if(($settings['sendmail_admin'] == 1) AND ($noemail == 0))
 				{
 				$date = date("d"."/"."m"."/"."Y");
 				$time = date("H".":"."i");
-				
+
 				$url_to_gb = "http://".$settings['h_domain'].$settings['gb_path']."admin/admin.php";
-				
-				$lang['sendmail_admin_title'] = format_mail(repl_uml($lang['sendmail_admin_title'], $charset), $_POST['name'], $date, $time, xhtmlbr2nl($_POST['message']), $settings['h_domain'], $url_to_gb, "", "", "", "", "", "");
-				$settings['sendmail_admin_text'] = format_mail(repl_uml($settings['sendmail_admin_text'], $charset), $_POST['name'], $date, $time, xhtmlbr2nl($_POST['message']), $settings['h_domain'], $url_to_gb, "", "", "", "", "", "");
-				
-				$mail_header = "content-type: text/plain; charset=".$charset."\n";
-				$mail_header .= "from: ".$settings['admin_gbemail']; 
-				
-				if (@mail($settings['admin_email'], $lang['sendmail_admin_title'], $settings['sendmail_admin_text'], $mail_header) )
+
+				$lang['sendmail_admin_title'] = format_mail(repl_uml($lang['sendmail_admin_title'], $charset), $_POST['email_name'], $date, $time, xhtmlbr2nl($_POST['email_message']), $settings['h_domain'], $url_to_gb, "", "", "", "", "", "");
+				$settings['sendmail_admin_text'] = format_mail(repl_uml($settings['sendmail_admin_text'], $charset), $_POST['email_name'], $date, $time, xhtmlbr2nl($_POST['email_message']), $settings['h_domain'], $url_to_gb, "", "", "", "", "", "");
+
+				$mail_header = "content-type: text/plain; charset=".$charset."\r\n";
+				$mail_header .= "from: ".$settings['admin_gbemail']."\r\n";
+				$mail_header .= "Reply-To: ".$settings['admin_gbemail']."\r\n";
+				$mail_header .= "X-Mailer: PHP/".phpversion();
+
+				if(@mail($settings['admin_email'], $lang['sendmail_admin_title'], $settings['sendmail_admin_text'], $mail_header) )
 					{
 					$sendemail_successfull = 1;
 					}
@@ -391,22 +410,31 @@
 					$sendemail_successfull = 0;
 					}
 				}
-			
+
 			// send an email to user
-			if($settings['sendmail_user'] == 1 AND isset($_POST['email']) AND ($noemail == 0))
+			if($settings['sendmail_user'] == 1 AND !empty($_POST['email']) AND ($noemail == 0))
 				{
 				$date = date("d"."/"."m"."/"."Y");
 				$time = date("H".":"."i");
-				
+
 				$url_to_gb = "http://".$settings['h_domain'].$settings['gb_path']."index.php";
-				
-				$lang['sendmail_user_title'] = format_mail(repl_uml($lang['sendmail_user_title'], $charset), $_POST['name'], $date, $time, xhtmlbr2nl($_POST['message']), $settings['h_domain'], $url_to_gb, "", "", "", "", "", "");
-				$settings['sendmail_user_text'] = format_mail(repl_uml($settings['sendmail_user_text'], $charset), $_POST['name'], $date, $time, xhtmlbr2nl($_POST['message']), $settings['h_domain'], $url_to_gb, "", "", "", "", "", "");
-				
-				$mail_header = "content-type: text/plain; charset=".$charset."\n";
-				$mail_header .= "from: ".$settings['admin_gbemail']; 
-				
-				if (@mail($_POST['email'], $lang['sendmail_user_title'], $settings['sendmail_user_text'], $mail_header) )
+
+				$lang['sendmail_user_title'] = format_mail(repl_uml($lang['sendmail_user_title'], $charset), $_POST['email_name'], $date, $time, xhtmlbr2nl($_POST['email_message']), $settings['h_domain'], $url_to_gb, "", "", "", "", "", "");
+				if($settings['moderated'] == 0)
+				  {
+				  $settings['sendmail_user_text'] = format_mail(repl_uml($settings['sendmail_user_text'], $charset), $_POST['email_name'], $date, $time, xhtmlbr2nl($_POST['email_message']), $settings['h_domain'], $url_to_gb, "", "", "", "", "", "");
+				  }
+				else
+				  {
+				  $settings['sendmail_user_text'] = format_mail(repl_uml($settings['sendmail_user_text_moderated'], $charset), $_POST['email_name'], $date, $time, xhtmlbr2nl($_POST['email_message']), $settings['h_domain'], $url_to_gb, "", "", "", "", "", "");
+				  }
+
+				$mail_header = "content-type: text/plain; charset=".$charset."\r\n";
+				$mail_header .= "from: ".$settings['admin_gbemail']."\r\n";
+				$mail_header .= "Reply-To: ".$settings['admin_gbemail']."\r\n";
+				$mail_header .= "X-Mailer: PHP/".phpversion();
+
+				if(@mail($_POST['email'], $lang['sendmail_user_title'], $settings['sendmail_user_text'], $mail_header) )
 					{
 					$sendemail_successfull = 1;
 					}
@@ -418,7 +446,7 @@
 
 			$entry_successfull = 1;
 
-			if (isset($settings['time_lock']) AND $settings['time_lock'] == 1)
+			if(isset($settings['time_lock']) AND $settings['time_lock'] == 1)
 				{
 				session_unset();
 				session_destroy();
@@ -430,14 +458,14 @@
 			}
 		else
 			{
-			if ($errorcode == 1) { $errormessage = $lang['errormessage1']; } // empty message
-			if ($errorcode == 2) { $errormessage = $lang['errormessage2']; } // empty email
-			if ($errorcode == 3) { $errormessage = $lang['errormessage3']; } // empty name
-			if ($errorcode == 4) { $errormessage = $_POST['email']."&nbsp;".$lang['errormessage4']; } // email not valid
-			if ($errorcode == 5) { $errormessage = $_POST['icq']."&nbsp;".$lang['errormessage5']; } // icq# not valid
-			if ($errorcode == 7) { $errormessage = $lang['errormessage7']; } // captcha not valid
-			if ($errorcode == 10) { $errormessage = $lang['errormessage10']; } // flood protection
-			if ($errorcode == 11) { $errormessage = $lang['errormessage11']; } // akismet
+			if($errorcode == 1) { $errormessage = $lang['errormessage1']; } // empty message
+			if($errorcode == 2) { $errormessage = $lang['errormessage2']; } // empty email
+			if($errorcode == 3) { $errormessage = $lang['errormessage3']; } // empty name
+			if($errorcode == 4) { $errormessage = $_POST['email']."&nbsp;".$lang['errormessage4']; } // email not valid
+			if($errorcode == 5) { $errormessage = $_POST['icq']."&nbsp;".$lang['errormessage5']; } // icq# not valid
+			if($errorcode == 7) { $errormessage = $lang['errormessage7']; } // captcha not valid
+			if($errorcode == 10) { $errormessage = $lang['errormessage10']; } // flood protection
+			if($errorcode == 11) { $errormessage = $lang['errormessage11']; } // akismet
 
 			// do not refresh site
 			$refresh = "";
@@ -446,13 +474,11 @@
 			if(($settings['captcha'] == 1) AND ($captcha_generated != 1))
 				{
 				generate_captcha($settings['captcha_method']);
-				$captcha_img = "<img src=''includes/captcha.inc.php'' class=''captcha'' title=''".$lang['security_code']."'' alt=''".$lang['security_code']."''>";
-				$captcha_img = template("CAPTCHA_IMG", $captcha, $content_captcha);
 				$captcha_generated = 1;
 				}
-			elseif ($settings['captcha'] == 0)
+			elseif($settings['captcha'] == 0)
 				{
-				$captcha_img = "";
+				$content_captcha = "";
 				}
 			}
 		// don't show preview here
@@ -461,30 +487,21 @@
 	else
 		{
 		// maybe preview button has been pushed instead?
-
-		if (isset($_POST['preview']) AND $_POST['preview'] == $lang['preview'] AND $_POST['message'] != "")
+		if(isset($_POST['preview']) AND $_POST['preview'] == $lang['preview'] AND !empty($_POST['message']))
 			{
-			$_POST['name'] = cleanstr($_POST['name']);
-			$_POST['city'] = cleanstr($_POST['city']);
-			$_POST['message'] = cleanstr($_POST['message']);
-			$_POST['email'] = cleanstr($_POST['email']);
-			$_POST['icq'] = cleanstr($_POST['icq']);
-			$_POST['aim'] = cleanstr($_POST['aim']);
-			$_POST['msn'] = cleanstr($_POST['msn']);
-			$_POST['hp'] = cleanstr($_POST['hp']);
 			$preview_message = nl2br($_POST['message']);
 			$t1 = chr(10);
 			$t2 = chr(13);
 			$preview_message = str_ireplace($t1, '', $preview_message);
 			$preview_message = str_ireplace($t2, '', $preview_message);
 
-			if (!$settings['wordwrap'] == 0)
+			if(!$settings['wordwrap'] == 0)
 				{
 				$preview_message = textWrap($preview_message, $settings['wordwrap']);
 				}
 
 			// set smilies
-			if ($settings['smileys'] == 1)
+			if($settings['smileys'] == 1)
 				{
 				$preview_message = set_smilies($preview_message);
 				}
@@ -503,7 +520,47 @@
 				$preview_message = bbcode_delete($preview_message);
 				}
 
+			if(isset($settings['gravatar_show']) AND ($settings['gravatar_show'] == 1) AND (!empty($_POST['email'])))
+				{
+				// load gravatar
+				if($settings['gravatar_rating'] == 0) { $gravatar_rating = "G"; }
+				if($settings['gravatar_rating'] == 1) { $gravatar_rating = "PG"; }
+				if($settings['gravatar_rating'] == 2) { $gravatar_rating = "R"; }
+				if($settings['gravatar_rating'] == 3) { $gravatar_rating = "X"; }
+				if($settings['gravatar_type'] == 0) { $gravatar_type = "&amp;f=y"; }
+				if($settings['gravatar_type'] == 1) { $gravatar_type = "&amp;d=mm"; }
+				if($settings['gravatar_type'] == 2) { $gravatar_type = "&amp;d=identicon"; }
+				if($settings['gravatar_type'] == 3) { $gravatar_type = "&amp;d=monsterid"; }
+				if($settings['gravatar_type'] == 4) { $gravatar_type = "&amp;d=wavatar"; }
+				if($settings['gravatar_type'] == 5) { $gravatar_type = "&amp;d=retro"; }
+
+				$gravatar_url = "http://www.gravatar.com/avatar/".md5(strtolower(trim($_POST['email'])))."?s=".$settings['gravatar_size']."&amp;r=".$gravatar_rating.$gravatar_type;
+				$img_gravatar = "<img src=\"".$gravatar_url."\" class=\"gravatar\" style=\"width: ".$settings['gravatar_size']."px; height: ".$settings['gravatar_size']."px;\" alt=\"".$lang['gravatar']."\" title=\"".$lang['gravatar']."\">";
+				}
+			 else
+				{
+				$gravatar_size = 0;
+				$img_gravatar = "";
+				}
+
+			$gravatar = template("IMG_GRAVATAR", $img_gravatar, $content_newentry_preview_gravatar);
+
+			if($settings['gravatar_position'] == 0)
+				{
+				$content_newentry_preview = template("ENTRY_GRAVATAR_LEFT", $gravatar, $content_newentry_preview);
+				$content_newentry_preview = template("ENTRY_GRAVATAR_RIGHT", "", $content_newentry_preview);
+				$content_newentry_preview = template("GRAVATAR_CSS", "entry_message_gravatar_left", $content_newentry_preview);
+				}
+			else
+				{
+				$content_newentry_preview = template("ENTRY_GRAVATAR_LEFT", "", $content_newentry_preview);
+				$content_newentry_preview = template("ENTRY_GRAVATAR_RIGHT", $gravatar, $content_newentry_preview);
+				$content_newentry_preview = template("GRAVATAR_CSS", "entry_message_gravatar_right", $content_newentry_preview);
+				}
+
 			$content_newentry_preview = template("TEMPLATE_ENTRY_MESSAGE", $preview_message, $content_newentry_preview);
+			$content_newentry_preview = template("GRAVATAR_SIZE", $settings['gravatar_size'], $content_newentry_preview);
+			$content_newentry_preview = template("ENTRY_NAME", $_POST['name'], $content_newentry_preview);
 			}
 		else
 			{
@@ -514,7 +571,7 @@
 		$refresh = "";
 
 		// check for ip
-		if ($settings['ipblocker'] == 1)
+		if($settings['ipblocker'] == 1)
 			{
 			$sql = "SELECT lastIP FROM ".$db['prefix']."lastip LIMIT 1";
 			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 514: ".mysql_error());
@@ -524,21 +581,19 @@
 			$lastIP = @mysql_fetch_array($result);
 			}
 
-		if(!isset($lastIP)) { $lastIP = NULL; }
+		if(!isset($lastIP)) { $lastIP = ""; }
 
-		if ($lastIP == $_SERVER["REMOTE_ADDR"]) { $errorcode = 6;  $errormessage = $lang['errormessage6']; } // ip was blocked
+		if($lastIP == $_SERVER["REMOTE_ADDR"]) { $errorcode = 6;  $errormessage = $lang['errormessage6']; } // ip was blocked
 
 		// generate captchacode if activated
 		if(($settings['captcha'] == 1) AND ($captcha_generated != 1))
 			{
 			generate_captcha($settings['captcha_method']);
-			$captcha_img = "<img src=''includes/captcha.inc.php'' class=''captcha'' title=''".$lang['security_code']."'' alt=''".$lang['security_code']."''>";
-			$captcha_img = template("CAPTCHA_IMG", $captcha, $content_captcha);
 			$captcha_generated = 1;
 			}
-		elseif ($settings['captcha'] == 0)
+		elseif($settings['captcha'] == 0)
 			{
-			$captcha_img = "";
+			$content_captcha = "";
 			}
 		}
 
@@ -548,7 +603,7 @@
 	$page_header = $content_header;
 
 	// check if "install" directory has been deleted
-	if (file_exists("install"))
+	if(file_exists("install"))
 		{
 		$page_header = template("INSTALL_DIRECTORY_EXISTS", "<div style='background-color: white; padding: 3px; border: 2px solid black; width: 500px;'><span style='color: red; font-size: 12px; font-weight: bold;'>".$lang['install_directory_exists']."</span></div>", $page_header);
 		}
@@ -565,13 +620,13 @@
 	$page_header = template("H_CHARSET", $charset, $page_header);
 	$page_header = template("REFRESH", $refresh, $page_header);
 
-	if (!isset($errorcode))
+	if(!isset($errorcode))
 		{
-		$content_errormessage = NULL;
+		$content_errormessage = "";
 		}
 
 	// Add smilies if activated
-	if ($settings['smileys'] == 1)
+	if($settings['smileys'] == 1)
 		{
 		$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 570: ".mysql_error());
 		@mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 571: ".mysql_error());
@@ -583,7 +638,7 @@
 			$smilies[$i] = mysql_fetch_array($result);
 			}
 
-		if(!isset($smilies)) { $smilies = NULL; }
+		if(!isset($smilies)) { $smilies = ""; }
 
 		$smiley_counter = 0;
 
@@ -591,24 +646,24 @@
 			{
 			$smiley_counter++;
 			$smiley_counter_2++;
-			if (($smiley_counter == $settings['smileys_break']) AND ($smiley_counter_2 != count($smilies)))
+			if(($smiley_counter == $settings['smileys_break']) AND ($smiley_counter_2 != count($smilies)))
 				{
-				if (preg_match("/,/is", $smilies[$i]['replacement'], $treffer))
+				if(preg_match("/,/is", $smilies[$i]['replacement'], $treffer))
 					{
 					$repl = explode(", ", $smilies[$i]['replacement']);
 					$smilies[$i]['replacement'] = $repl[0];
 					}
-				$smilies_loop = "<a href='javascript&#058;AddSmiley(\"".$smilies[$i]['replacement']."\")'><img src='images/smilies/".$smilies[$i]['path']."' width='".$smilies[$i]['width']."' height='".$smilies[$i]['height']."' alt='".$smilies[$i]['replacement']."' title='".$smilies[$i]['replacement']."'></a><br>&nbsp;";
+				$smilies_loop = "<a href='javascript&#058;AddSmiley(\"".$smilies[$i]['replacement']."\")'><img src='images/smilies/".$smilies[$i]['path']."' class='smilies' width='".$smilies[$i]['width']."' height='".$smilies[$i]['height']."' alt='".$smilies[$i]['replacement']."' title='".$smilies[$i]['replacement']."'></a><br>&nbsp;";
 				$smiley_counter = 0;
 				}
 			else
 				{
-				if (preg_match("/,/is", $smilies[$i]['replacement'], $treffer))
+				if(preg_match("/,/is", $smilies[$i]['replacement'], $treffer))
 					{
 					$repl = explode(", ", $smilies[$i]['replacement']);
 					$smilies[$i]['replacement'] = $repl[0];
 					}
-				$smilies_loop = "<a href='javascript&#058;AddSmiley(\"".$smilies[$i]['replacement']."\")'><img src='images/smilies/".$smilies[$i]['path']."' width='".$smilies[$i]['width']."' height='".$smilies[$i]['height']."' alt='".$smilies[$i]['replacement']."' title='".$smilies[$i]['replacement']."'></a>&nbsp;";
+				$smilies_loop = "<a href='javascript&#058;AddSmiley(\"".$smilies[$i]['replacement']."\")'><img src='images/smilies/".$smilies[$i]['path']."' class='smilies' width='".$smilies[$i]['width']."' height='".$smilies[$i]['height']."' alt='".$smilies[$i]['replacement']."' title='".$smilies[$i]['replacement']."'></a>&nbsp;";
 				}
 			$smilies_replace .= $smilies_loop;
 			}
@@ -617,10 +672,10 @@
 		}
 	else
 		{
-		$content_newentry_smileys = NULL;
+		$content_newentry_smileys = "";
 		}
 
-	if ($settings['bbcode'] == 1)
+	if($settings['bbcode'] == 1)
 		{
 		$content_newentry_bbcodes = template("LANG_BBCODES", $lang['bbcodes'], $content_newentry_bbcodes);
 		$content_newentry_bbcodes = template("LANG_BBCODE_BOLD", $lang['bbcode_bold'], $content_newentry_bbcodes);
@@ -662,57 +717,91 @@
 		}
 	else
 		{
-		$bbcodes = NULL;
+		$bbcodes = "";
 		}
 
-	// insert template if user_notification == 1
-	if ($settings['user_notification'] == 1)
+	// insert template for user_notification checkbox
+	if($settings['user_notification'] == 1 AND $settings['moderated'] == 1)
 		{
-		$content_newentry_user_notification = template("LANG_USER_NOTIFICATION", $lang['user_notification'], $content_newentry_user_notification);
-		$user_notification = $content_newentry_user_notification;
+		if($settings['require_email'] == 1 OR !empty($_POST['email']))
+			{
+			$content_newentry_user_notification = template("LANG_USER_NOTIFICATION", $lang['user_notification'], $content_newentry_user_notification);
+			if(isset($_POST['send']) OR isset($_POST['preview']) OR isset($_POST['refresh_captcha']))
+				{
+				if(isset($_POST['user_notification']) AND $_POST['user_notification'] == 1)
+					{
+					$content_newentry_user_notification = template("CHECKED", " checked='checked'", $content_newentry_user_notification);
+					}
+				else
+					{
+					$content_newentry_user_notification = template("CHECKED", "", $content_newentry_user_notification);
+					}
+				}
+			else
+				{
+				$content_newentry_user_notification = template("CHECKED", " checked='checked'", $content_newentry_user_notification);
+				}
+			$user_notification = $content_newentry_user_notification;
+			}
 		}
 	else
 		{
-		$user_notification = NULL;
+		$user_notification = "";
 		}
 
 	// insert template if user_show_email == 1
-	if ($settings['user_show_email'] == 1)
+	if($settings['user_show_email'] == 1)
 		{
-		$content_newentry_user_show_email = template("LANG_USER_SHOW_EMAIL", $lang['user_show_email'], $content_newentry_user_show_email);
-		$user_show_email = $content_newentry_user_show_email;
+		if($settings['require_email'] == 1 OR !empty($_POST['email']))
+			{
+			$content_newentry_user_show_email = template("LANG_USER_SHOW_EMAIL", $lang['user_show_email'], $content_newentry_user_show_email);
+			if(isset($_POST['send']) OR isset($_POST['preview']) OR isset($_POST['refresh_captcha']))
+				{
+				if(isset($_POST['user_show_email']) AND $_POST['user_show_email'] == 1)
+					{
+					$content_newentry_user_show_email = template("CHECKED", " checked='checked'", $content_newentry_user_show_email);
+					}
+				else
+					{
+					$content_newentry_user_show_email = template("CHECKED", "", $content_newentry_user_show_email);
+					}
+				}
+			else
+				{
+				$content_newentry_user_show_email = template("CHECKED", " checked='checked'", $content_newentry_user_show_email);
+				}
+			$user_show_email = $content_newentry_user_show_email;
+			}
 		}
 	else
 		{
-		$user_show_email = NULL;
+		$user_show_email = "";
 		}
 
 	// insert template if akismet is acitvated
-	if (file_exists("plugins/akismet/akismet.class.php") AND (isset($settings['akismet_plugin'])) AND ($settings['akismet_plugin'] == 1))
+	if(file_exists("plugins/akismet/akismet.class.php") AND (isset($settings['akismet_plugin'])) AND ($settings['akismet_plugin'] == 1))
 		{
 		$content_newentry_user_accept_akismet_service = template("LANG_USER_ACCEPT_AKISMET_SERVICE", $lang['user_accept_akismet_service'], $content_newentry_user_accept_akismet_service);
 		$user_accept_akismet_service = $content_newentry_user_accept_akismet_service;
 		}
 	else
 		{
-		$user_accept_akismet_service = NULL;
+		$user_accept_akismet_service = "";
 		}
 
 	// fill template with captcha
 	if(($settings['captcha'] == 1) AND ($captcha_generated != 1))
 		{
 		generate_captcha($settings['captcha_method']);
-		$captcha_img = "<img src='includes/captcha.inc.php' class='captcha' title='".$lang['security_code']."' alt='".$lang['security_code']."'>";
-		$captcha_img = template("CAPTCHA_IMG", $captcha, $content_captcha);
 		$captcha_generated = 1;
 		}
-	elseif ($settings['captcha'] == 0)
+	elseif($settings['captcha'] == 0)
 		{
-		$captcha_img = "";
+		$content_captcha = "";
 		}
 
 	 // entry was not successfull or it is the first time the site was loaded
-	if (!isset($entry_successfull))
+	if(!isset($entry_successfull))
 		{
 		// get data from template
 		$page_newentry_body = $content_newentry_body;
@@ -726,7 +815,7 @@
 		$page_newentry_body = template("TEMPLATE_USER_NOTIFICATION", $user_notification, $page_newentry_body);
 		$page_newentry_body = template("TEMPLATE_USER_SHOW_EMAIL", $user_show_email, $page_newentry_body);
 		$page_newentry_body = template("TEMPLATE_USER_ACCEPT_AKISMET_SERVICE", $user_accept_akismet_service, $page_newentry_body);
-		$page_newentry_body = template("TEMPLATE_CAPTCHA", $captcha_img, $page_newentry_body);
+		$page_newentry_body = template("TEMPLATE_CAPTCHA", $content_captcha, $page_newentry_body);
 		$page_newentry_body = template("TEMPLATE_COPYRIGHT", $content_copyright, $page_newentry_body);
 		$page_newentry_body = template("TEMPLATE_FOOTER", $content_footer, $page_newentry_body);
 		$page_newentry_body = template("MGB_VERSION", $settings['version'], $page_newentry_body);
@@ -736,7 +825,7 @@
 		$page_newentry_body = template("TEMPLATE_STYLE_PATH", $settings['template_style_path'], $page_newentry_body);
 
 		// fill template with language strings
-		if(!isset($errormessage)) { $errormessage = NULL; }
+		if(!isset($errormessage)) { $errormessage = ""; }
 		$page_newentry_body = template("ERRORMESSAGE", $errormessage, $page_newentry_body);
 		$page_newentry_body = template("TIME_LOCK_REST", $rest, $page_newentry_body);
 		$page_newentry_body = template("TITLE", $settings['title'], $page_newentry_body);
@@ -751,6 +840,7 @@
 		$page_newentry_body = template("LANG_NEW_ENTRY_MESSAGE", $lang['message'], $page_newentry_body);
 		$page_newentry_body = template("LANG_NECESSARY_FIELDS", $lang['necessary_fields'], $page_newentry_body);
 		$page_newentry_body = template("LANG_SMILEYS", $lang['smileys'], $page_newentry_body);
+		$page_newentry_body = template("LANG_CAPTCHA_REFRESH", $lang['captcha_refresh'], $page_newentry_body);
 		$page_newentry_body = template("LANG_CAPTCHA_WHAT_IS_THAT", $lang['captcha_what_is_that'], $page_newentry_body);
 		$page_newentry_body = template("LANG_CAPTCHA_WIKIPEDIA", $lang['captcha_wikipedia'], $page_newentry_body);
 		$page_newentry_body = template("LANG_CAPTCHA_TOOLTIP", $lang['captcha_tooltip'], $page_newentry_body);
@@ -762,8 +852,7 @@
 		$page_newentry_body = template("LANG_ADMINPANEL_DESCR", $lang['adminpanel_descr'], $page_newentry_body);
 		$page_newentry_body = template("LANG_ADMINPANEL", $lang['adminpanel'], $page_newentry_body);
 
-
-		// fill template with sent strings
+      // fill template with sent strings
 		if(!isset($_POST['sent']))
 			{
 			$_POST['name'] = "";
@@ -787,6 +876,14 @@
 
 		// fill template with general data
 		$page_newentry_body = template("FORM_ACTION", "newentry.php", $page_newentry_body);
+		if($settings['require_email'] == 1)
+			{
+			$page_newentry_body = template("EMAIL_NECESSARY", "*", $page_newentry_body);
+			}
+		else
+			{
+			$page_newentry_body = template("EMAIL_NECESSARY", "&nbsp;", $page_newentry_body);
+			}
 		}
 	else
 		{
@@ -802,7 +899,7 @@
 
 		// then strings
 		$page_newentry_body = template("TITLE", $settings['title'], $page_newentry_body);
-		if ($settings['moderated'] == 1) { $page_newentry_body = template("LANG_ENTRY_SUCCESS", $lang['entry_success_mod'], $page_newentry_body); } else { $page_newentry_body = template("LANG_ENTRY_SUCCESS", $lang['entry_success'], $page_newentry_body); }
+		if($settings['moderated'] == 1) { $page_newentry_body = template("LANG_ENTRY_SUCCESS", $lang['entry_success_mod'], $page_newentry_body); } else { $page_newentry_body = template("LANG_ENTRY_SUCCESS", $lang['entry_success'], $page_newentry_body); }
 		$page_newentry_body = template("LANG_FORWARDING", $lang['forwarding'], $page_newentry_body);
 		$page_newentry_body = template("LANG_BACK", $lang['back'], $page_newentry_body);
 		$page_newentry_body = template("LANG_BACK_TO_MAINPAGE", $lang['back_to_mainpage'], $page_newentry_body);
